@@ -36,8 +36,9 @@
 #include <qvaluelist.h>
 #include <ktempfile.h>
 #include "cvoxstormglobal.h"
-#include "cecaiamanager.h"
 #include "cewf.h"
+#include "cecaladspaeffect.h"
+#include "cecaiamanager.h"
 
 /////////////////////////////////////////////////////////////////////////////
 
@@ -48,15 +49,12 @@ CEcaIAManager::CEcaIAManager()
   nMasterPosition = 0;
   rStatus = NotRunning;
   nBufferSize = 1024;
-  //! \todo 󥻥åȥå "TEMP" ơ
-  //! (ÿ֤)νԤ
 }
 
 /////////////////////////////////////////////////////////////////////////////
 
 CEcaIAManager::~CEcaIAManager()
 {
-  //! \todo 󥻥åȥå "TEMP" 롣
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -343,6 +341,12 @@ CEcaIAManager::slotMixdown(
       slotToggleMute((*it).strTrackName, (*it).bMute);
     }
 
+    // setup bypass condition !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    // if already this name track is existing...???
+    if ( (*it).bBypass ) {
+      slotToggleBypass((*it).strTrackName, (*it).bBypass);
+    }
+
     // NOTE : don't change order after parameter (level, pan, ...)
     // CEcaIAManager object processes implicitly this order
     // setup level
@@ -355,6 +359,16 @@ CEcaIAManager::slotMixdown(
     command(strCommand);
     slotChangePan((*it).strTrackName, (*it).nPan);
 
+    // setup effects
+    QValueVector<CLadspaEffect>::const_iterator itFx = (*it).vEffects.begin();
+    while ( itFx != (*it).vEffects.end() ) {
+      CEcaLadspaEffect fxTmp(*itFx);
+      strCommand = "cop-add " + fxTmp.settingInEcaFormat();
+      command(strCommand);
+      itFx++;
+    }
+    slotChangeEffects((*it).strTrackName, (*it).vEffects);
+    
     it++;
   }
 
@@ -379,54 +393,69 @@ CEcaIAManager::slotMixdown(
 /////////////////////////////////////////////////////////////////////////////
 
 void
-CEcaIAManager::slotAddChain(const CTrackInf& TrackInfAdd)
+CEcaIAManager::slotAddChain(const CTrackInf& trackInfAdd)
 {
   // if no input or no output, not be added
-  QFileInfo FileInfo(TrackInfAdd.strFileName);
-  if ( TrackInfAdd.strFileName.isEmpty() ) {
+  QFileInfo FileInfo(trackInfAdd.strFileName);
+  if ( trackInfAdd.strFileName.isEmpty() ) {
     return;
-  } else if ( (!TrackInfAdd.bRecPort && !FileInfo.exists() ) || 
-              !CVoxStormGlobal::isSupportedFileType(TrackInfAdd.strFileName) ) {
+  } else if ( (!trackInfAdd.bRecPort && !FileInfo.exists() ) || 
+              !CVoxStormGlobal::isSupportedFileType(trackInfAdd.strFileName) ) {
     return;
   } else {
-    if ( TrackInfAdd.bRecPort ) {
-      if ( TrackInfAdd.strInputDevice.isEmpty() ) {
+    if ( trackInfAdd.bRecPort ) {
+      if ( trackInfAdd.strInputDevice.isEmpty() ) {
         return;
       }
     } else {
-      if ( TrackInfAdd.strOutputDevice.isEmpty() ) {
+      if ( trackInfAdd.strOutputDevice.isEmpty() ) {
         return;
       }
     }
   }
 
   // should be push to vector AT FIRST for after process (other slots or functions)
-  vTrackChains.push_back(TrackInfAdd);
+  vTrackChains.push_back(trackInfAdd);
 
   // create chain
-  QString strCommand = "c-add " + TrackInfAdd.strTrackName;
+  QString strCommand = "c-add " + trackInfAdd.strTrackName;
   command(strCommand);
 
   // select chain
-  slotSelectChain(TrackInfAdd.strTrackName);
+  slotSelectChain(trackInfAdd.strTrackName);
 
   // setup mute condition !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   // if already this name track is existing...???
-  if ( TrackInfAdd.bMute ) {
-    slotToggleMute(TrackInfAdd.strTrackName, TrackInfAdd.bMute);
+  if ( trackInfAdd.bMute ) {
+    slotToggleMute(trackInfAdd.strTrackName, trackInfAdd.bMute);
+  }
+
+  // setup bypass condition !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+  // if already this name track is existing...???
+  if ( trackInfAdd.bBypass ) {
+    slotToggleBypass(trackInfAdd.strTrackName, trackInfAdd.bBypass);
   }
 
   // NOTE : don't change order after parameter (level, pan, ...)
   // CEcaIAManager object processes implicitly this order
   // setup level
-  strCommand = "cop-add -ea:" + QString("%1").arg(TrackInfAdd.nLevel);
+  strCommand = "cop-add -ea:" + QString("%1").arg(trackInfAdd.nLevel);
   command(strCommand);
-  slotChangeLevel(TrackInfAdd.strTrackName, TrackInfAdd.nLevel);
+  slotChangeLevel(trackInfAdd.strTrackName, trackInfAdd.nLevel);
 
   // setup pan
-  strCommand = "cop-add -epp:" + QString("%1").arg(TrackInfAdd.nPan);
+  strCommand = "cop-add -epp:" + QString("%1").arg(trackInfAdd.nPan);
   command(strCommand);
-  slotChangePan(TrackInfAdd.strTrackName, TrackInfAdd.nPan);
+  slotChangePan(trackInfAdd.strTrackName, trackInfAdd.nPan);
+
+  // setup effects
+  QValueVector<CLadspaEffect>::const_iterator itFx = trackInfAdd.vEffects.begin();
+  while ( itFx != trackInfAdd.vEffects.end() ) {
+    CEcaLadspaEffect fxTmp(*itFx);
+    strCommand = "cop-add " + fxTmp.settingInEcaFormat();
+    command(strCommand);
+    itFx++;
+  }
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -693,6 +722,64 @@ CEcaIAManager::slotChangeLength(
 
 /////////////////////////////////////////////////////////////////////////////
 
+void
+CEcaIAManager::slotChangeEffects(
+                 const QString& strTrackName,
+                 const QValueVector<CLadspaEffect>& effects)
+{
+  int nIndex;
+
+  if ( (nIndex = this->getIndexByName(strTrackName)) == -1 ) {
+    return;
+  }
+
+  vTrackChains[nIndex].vEffects = effects;
+
+  // select chain
+  slotSelectChain(strTrackName);
+
+  // remove old effects
+  command("cop-list", false);
+  QStringList strlCops = lastStringList();
+  int i;
+  int nCount = strlCops.size();
+  // ignore level and pan
+  for ( i = 2; i < nCount; i++ ) {
+    command("cop-select 3"); // 3 : first effect
+    command("cop-remove");
+  }
+
+  // setup effects
+  QString strCommand;
+  CTrackInf track(vTrackChains[nIndex]);
+  QValueVector<CLadspaEffect>::const_iterator itFx = track.vEffects.begin();
+  while ( itFx != track.vEffects.end() ) {
+    CEcaLadspaEffect fxTmp(*itFx);
+    strCommand = "cop-add " + fxTmp.settingInEcaFormat();
+    command(strCommand);
+    itFx++;
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void
+CEcaIAManager::slotToggleBypass(const QString& strTrackName, bool bBypass)
+{
+  int nIndex;
+
+  if ( (nIndex = this->getIndexByName(strTrackName)) == -1 ) {
+    return;
+  }
+
+  vTrackChains[nIndex].bBypass = bBypass;
+
+  slotSelectChain(strTrackName);
+  command("c-bypass");
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 inline void
 CEcaIAManager::slotSelectChain(const QString& strTrackName)
 {
