@@ -136,27 +136,45 @@ public slots:
   void slotRemoveAllOutputs();
 
   //! \brief ץ쥤ХåǥХѹ
+  //! ꥢ륿ǥŬѤʤ
   void slotChangePlaybackDevice(const QString& strTrackName,
                                 const QString& strDevice);
   //! \brief 쥳ǥ󥰥ǥХѹ
+  //! ꥢ륿ǥŬѤʤ
   void slotChangeRecordingDevice(const QString& strTrackName,
                                  const QString& strDevice);
   //! \brief ե̾ѹ
+  //! ꥢ륿ǥŬѤʤ
   void slotChangeFileName(const QString& strTrackName, const QString& strFileName);
   //! \brief ٥ѹ
+  //! ꥢ륿ǥŬѤ롣
   void slotChangeLevel(const QString& strTrackName, int nLevel);
   //! \brief ѥѹ
+  //! ꥢ륿ǥŬѤ롣
   void slotChangePan(const QString& strTrackName, int nPan);
   //! \brief ߥ塼Ⱦѹ
+  //! ꥢ륿ǥŬѤ롣
   void slotToggleMute(const QString& strTrackName, bool bMute);
   //! \brief Ͽѹ
+  //! ꥢ륿ǥŬѤʤ
   void slotToggleRec(const QString& strTrackName, bool bRec);
   //! \brief ϰѹ
+  //! ꥢ륿ǥŬѤʤ
   void slotChangeStartPosition(const QString& strTrackName, const QTime& StartPosition);
   //! \brief եåѹ
+  //! ꥢ륿ǥŬѤʤ
   void slotChangeOffset(const QString& strTrackName, const QTime& Offset);
   //! \brief Ĺѹ
+  //! ꥢ륿ǥŬѤʤ
   void slotChangeLength(const QString& strTrackName, const QTime& Length);
+  //! \brief եѹ
+  //! ꥢ륿ǥŬѤʤ
+  void slotChangeEffects(
+         const QString& strTrackName, 
+         const QValueVector<CLadspaEffect>& effects);
+  //! \brief Хѥѹ
+  //! ꥢ륿ǥŬѤ롣
+  void slotToggleBypass(const QString& strTrackName, bool bBypass);
 
 private:
   //! \brief ԡ󥹥ȥ饯ԡػߤ뤿ᡢprivate
