@@ -15,8 +15,11 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <qdir.h>
 #include <qfileinfo.h>
 #include <qregexp.h>
+#include <klocale.h>
+#include <kmessagebox.h>
 #include "cvoxstormglobal.h"
 
 /////////////////////////////////////////////////////////////////////////////
@@ -238,3 +241,164 @@ CVoxStormGlobal::setupReservedStringList()
 }
 
 /////////////////////////////////////////////////////////////////////////////
+
+QString 
+CVoxStormGlobal::permissionInUNIXFormat(const QString& strFileName)
+{
+  QFileInfo fileInfo(strFileName);
+
+  if ( !fileInfo.exists() ) {
+    return "";
+  }
+
+  QString strResult;
+
+  if ( fileInfo.isSymLink() ) {
+    strResult += "l";
+  } else if ( fileInfo.isFile() ) {
+    strResult += "-";
+  } else if ( fileInfo.isDir() ) {
+    strResult += "d";
+  }
+
+  // owner
+  if ( fileInfo.permission(QFileInfo::ReadOwner) ) {
+    strResult += "r";
+  } else {
+    strResult += "-";
+  }
+
+  if ( fileInfo.permission(QFileInfo::WriteOwner) ) {
+    strResult += "w";
+  } else {
+    strResult += "-";
+  }
+
+  if ( fileInfo.permission(QFileInfo::ExeOwner) ) {
+    strResult += "x";
+  } else {
+    strResult += "-";
+  }
+
+  // group
+  if ( fileInfo.permission(QFileInfo::ReadGroup) ) {
+    strResult += "r";
+  } else {
+    strResult += "-";
+  }
+
+  if ( fileInfo.permission(QFileInfo::WriteGroup) ) {
+    strResult += "w";
+  } else {
+    strResult += "-";
+  }
+
+  if ( fileInfo.permission(QFileInfo::ExeGroup) ) {
+    strResult += "x";
+  } else {
+    strResult += "-";
+  }
+
+  // other
+  if ( fileInfo.permission(QFileInfo::ReadOther) ) {
+    strResult += "r";
+  } else {
+    strResult += "-";
+  }
+
+  if ( fileInfo.permission(QFileInfo::WriteOther) ) {
+    strResult += "w";
+  } else {
+    strResult += "-";
+  }
+
+  if ( fileInfo.permission(QFileInfo::ExeOther) ) {
+    strResult += "x";
+  } else {
+    strResult += "-";
+  }
+
+  strResult += "  ";
+
+  strResult += fileInfo.owner() + "  ";
+  strResult += fileInfo.group() + "  ";
+  strResult += QString("%1").arg(fileInfo.size());
+  if ( fileInfo.isSymLink() ) {
+    strResult += "  -> " + fileInfo.readLink();
+  }
+
+  return strResult;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+QString 
+CVoxStormGlobal::homeDir()
+{
+  QDir dir;
+  return dir.homeDirPath();
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+QString 
+CVoxStormGlobal::absPath(const QString& strPath)
+{
+  QString strAbs = strPath;
+
+  // if strDirName starts with "~", convert "~" to user's home directory
+  if ( strAbs.startsWith("~") ){
+    QString strHome = homeDir();
+    if ( !strHome.endsWith("/") ) {
+      strAbs = strHome + "/" + strAbs.remove(0, 2);
+    } else {
+      strAbs = strHome + strAbs.remove(0, 2);
+    }
+  } else {
+    QFileInfo fileInfo = strPath;
+    strAbs = fileInfo.absFilePath();
+  }
+
+  return strAbs;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+bool 
+CVoxStormGlobal::queryAndCreateDir(
+  QWidget* WidgetParent, 
+  const QString& strDirName)
+{
+  QFileInfo fileInfo;
+  QString strAbs = absPath(strDirName);
+
+  fileInfo = strAbs;
+
+  if ( fileInfo.exists() ) {  // already exists
+    if ( fileInfo.isDir() ) { // the path is dir
+      return true;
+    } else {                  // the path is file
+      return false;
+    }
+  }
+
+  if ( KMessageBox::questionYesNo(
+         WidgetParent, 
+         QString(i18n("The directory \"%1\" does not exists. "
+                      "Are you sure you want to create it?").arg(strDirName)), 
+         "Create Directory?") != KMessageBox::Yes ) {
+    return false;
+  }
+
+  QDir dir;
+  if ( !dir.mkdir(strAbs) ) {
+    KMessageBox::error(
+      WidgetParent,
+      QString(i18n("Failed in creation directory.")));
+    return false;
+  }
+
+  return true;
+}
+
+/////////////////////////////////////////////////////////////////////////////
