@@ -162,6 +162,14 @@ WVoxBase::addTrack(
   connect(VoxTrackNew, SIGNAL(lengthChanged(const QTime&)), 
           SignalMapperLength, SLOT(map()));
 
+  SignalMapperEffects->setMapping(VoxTrackNew, strTrackName);
+  connect(VoxTrackNew, SIGNAL(effectsChanged(const QValueVector<CLadspaEffect>&)), 
+          SignalMapperEffects, SLOT(map()));
+
+  SignalMapperBypass->setMapping(VoxTrackNew, strTrackName);
+  connect(VoxTrackNew, SIGNAL(bypassToggled(bool)), 
+          SignalMapperBypass, SLOT(map()));
+
   connect(VoxTrackNew, SIGNAL(propertyDemanded(const CTrackInf&)),
           this, SLOT(slotDisplayProperty(const CTrackInf&)));
 
@@ -234,6 +242,14 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
     connect(VoxTrackNew, SIGNAL(lengthChanged(const QTime&)),
             SignalMapperLength, SLOT(map()));
 
+    SignalMapperEffects->setMapping(VoxTrackNew, strTrackName);
+    connect(VoxTrackNew, SIGNAL(effectsChanged(const QValueVector<CLadspaEffect>&)),
+            SignalMapperEffects, SLOT(map()));
+
+    SignalMapperBypass->setMapping(VoxTrackNew, strTrackName);
+    connect(VoxTrackNew, SIGNAL(bypassToggled(bool)),
+            SignalMapperBypass, SLOT(map()));
+
     connect(VoxTrackNew, SIGNAL(propertyDemanded(const CTrackInf&)),
             this, SLOT(slotDisplayProperty(const CTrackInf&)));
 
@@ -275,6 +291,8 @@ WVoxBase::clearTracks()
     SignalMapperStartPosition->removeMappings(vVoxTracks[i]);
     SignalMapperOffset->removeMappings(vVoxTracks[i]);
     SignalMapperLength->removeMappings(vVoxTracks[i]);
+    SignalMapperEffects->removeMappings(vVoxTracks[i]);
+    SignalMapperBypass->removeMappings(vVoxTracks[i]);
 
     delete vVoxTracks[i];
     vVoxTracks[i] = NULL;
@@ -320,6 +338,8 @@ WVoxBase::removeTrack(const QString& strTrackName)
       SignalMapperStartPosition->removeMappings(vVoxTracks[i]);
       SignalMapperOffset->removeMappings(vVoxTracks[i]);
       SignalMapperLength->removeMappings(vVoxTracks[i]);
+      SignalMapperEffects->removeMappings(vVoxTracks[i]);
+      SignalMapperBypass->removeMappings(vVoxTracks[i]);
 
       VLayoutTracks->remove(vVoxTracks[i]);
 
@@ -428,6 +448,14 @@ WVoxBase::setupWidgets()
   connect(SignalMapperLength, SIGNAL(mapped(const QString&)),
           this, SLOT(slotChangeLength(const QString&)));
 
+  SignalMapperEffects = new QSignalMapper(this);
+  connect(SignalMapperEffects, SIGNAL(mapped(const QString&)),
+          this, SLOT(slotChangeEffects(const QString&)));
+
+  SignalMapperBypass = new QSignalMapper(this);
+  connect(SignalMapperBypass, SIGNAL(mapped(const QString&)),
+          this, SLOT(slotToggleBypass(const QString&)));
+
   QVBox       *VBoxBase = new QVBox(this);
   QWidget     *WidgetMisc = new QWidget(VBoxBase);
   QHBoxLayout *HBoxLayout = new QHBoxLayout(WidgetMisc);
@@ -866,6 +894,24 @@ WVoxBase::slotChangeLength(const QString& strTrackName)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void
+WVoxBase::slotChangeEffects(const QString& strTrackName)
+{
+  emit effectsChanged(strTrackName,
+		  vVoxTracks[getIndexByName(strTrackName)]->effects());
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void
+WVoxBase::slotToggleBypass(const QString& strTrackName)
+{
+  emit bypassToggled(strTrackName,
+		  vVoxTracks[getIndexByName(strTrackName)]->isBypassed());
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxBase::slotDisplayProperty(const CTrackInf& trackInf)
 {
