@@ -181,6 +181,10 @@ private:
   QSignalMapper *SignalMapperOffset;
   //! ȥåĹѹΤΥʥޥåѡ
   QSignalMapper *SignalMapperLength;
+  //! եѹΤΥʥޥåѡ
+  QSignalMapper *SignalMapperEffects;
+  //! ХѥѹΤΥʥޥåѡ
+  QSignalMapper *SignalMapperBypass;
 
   //! åĹ
   QTime         timeMaxSessionLength;
@@ -261,6 +265,15 @@ private slots:
   //! ǥʥȯ롣
   //! \param strTrackName ȥå̾Ρ
   void slotChangeLength(const QString& strTrackName);
+  //! \brief եѹФ륹åȡ
+  //! ǥʥȯ롣
+  //! \param strTrackName ȥå̾Ρ
+  void slotChangeEffects(const QString& strTrackName);
+  //! \brief ХѥѹФ륹åȡ
+  //! ǥʥȯ롣
+  //! \param strTrackName ȥå̾Ρ
+  void slotToggleBypass(const QString& strTrackName);
+
   //! \brief ץѥƥɽ륹åȡ
   //! \param trackInf ȥå
   void slotDisplayProperty(const CTrackInf& trackInf);
@@ -294,6 +307,10 @@ signals:
   void offsetChanged(const QString&, const QTime&);
   //! \brief ȥåĹѹΥʥ롣
   void lengthChanged(const QString&, const QTime&);
+  //! \brief եѹΥʥ롣
+  void effectsChanged(const QString&, const QValueVector<CLadspaEffect>&);
+  //! \brief ХѥѹΥʥ롣
+  void bypassToggled(const QString&, bool);
 
   //! \brief ֤ѹ줿Υʥ롣
   //! ᥤѹʤΤǡȥåϤʤ
