@@ -46,6 +46,7 @@
 #include "wmixdowndialog.h"
 #include "cvoxstormglobal.h"
 #include "worderdialog.h"
+#include "cladspafactory.h"
 
 /////////////////////////////////////////////////////////////////////////////
 
@@ -85,6 +86,8 @@ WVoxStorm::~WVoxStorm()
 
   delete ToggleActionRec;
   delete ToggleActionInteractive;
+
+  CLadspaFactory::destroyInstance();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -92,6 +95,8 @@ WVoxStorm::~WVoxStorm()
 void 
 WVoxStorm::initialize()
 {
+  CLadspaFactory::createInstance(getenv("LADSPA_PATH"));
+
   setupActions();
   setupStatusBar();
 
@@ -122,6 +127,12 @@ WVoxStorm::initialize()
           this, SLOT(slotChangeOffset(const QString&, const QTime&)));
   connect(VoxBase, SIGNAL(lengthChanged(const QString&, const QTime&)),
           this, SLOT(slotChangeLength(const QString&, const QTime&)));
+  connect(VoxBase, 
+          SIGNAL(effectsChanged(const QString&, const QValueVector<CLadspaEffect>&)),
+          this,
+          SLOT(slotChangeEffects(const QString&, const QValueVector<CLadspaEffect>&)));
+  connect(VoxBase, SIGNAL(bypassToggled(const QString&, bool)),
+          this, SLOT(slotToggleBypass(const QString&, bool)));
 
   connect(VoxBase, SIGNAL(masterPositionChanged(const QTime&)),
           &ecaIAManager, SLOT(slotSetMasterPosition(const QTime&)));
@@ -455,7 +466,7 @@ WVoxStorm::setupActions()
   menuBar()->insertItem(i18n("&Settings"), PopupMenu);
 
   QString strHelp =
-            i18n("VoxStorm 0.3\n\n"
+            i18n("VoxStorm 0.4\n\n"
                  "(C) 2003-2004 Tomoaki Murakami\n"
                  "solarisphere@yahoo.co.jp\n"
                  "Simple MTR using Ecasound on KDE\n");
@@ -1211,6 +1222,36 @@ WVoxStorm::slotChangeLength(
 
 /////////////////////////////////////////////////////////////////////////////
 
+void
+WVoxStorm::slotChangeEffects(
+             const QString& strTrackName,
+             const QValueVector<CLadspaEffect>& effects)
+{
+  if ( ToggleActionInteractive->isChecked() ) {
+    // NOTE :
+    // the track that has name as strTrackName is surely existing
+    // so we not check existence of the track
+
+    ecaIAManager.slotChangeEffects(strTrackName, effects);
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void
+WVoxStorm::slotToggleBypass(const QString& strTrackName, bool bBypass)
+{
+  if ( ToggleActionInteractive->isChecked() ) {
+    // NOTE :
+    // the track that has name as strTrackName is surely existing
+    // so we not check existence of the track
+
+    ecaIAManager.slotToggleBypass(strTrackName, bBypass);
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxStorm::slotChangedState()
 {
