@@ -231,6 +231,14 @@ private slots:
   //! \brief ȥå꤬ѹ줿Υåȡ
   //! Ĺѹ
   void slotChangeLength(const QString& strTrackName, const QTime& TimeLength);
+  //! \brief ȥå꤬ѹ줿Υåȡ
+  //! եѹ
+  void slotChangeEffects(
+         const QString& strTrackName, 
+         const QValueVector<CLadspaEffect>& effects);
+  //! \brief ȥå꤬ѹ줿Υåȡ
+  //! Хѥѹ
+  void slotToggleBypass(const QString& strTrackName, bool bBypass);
 
   //! \brief ֤ѹ줿Υåȡ
   void slotChangedState();
