@@ -151,6 +151,7 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
   QFont font = PushButtonMute->font();
   font.setPointSize(9);
   PushButtonMute->setFont(font);
+  PushButtonMute->setPaletteBackgroundColor(QColor(64, 64, 128));
   PushButtonMute->setPaletteForegroundColor(QColor(0, 255, 0));
   PushButtonMute->setText("M");
   PushButtonMute->setToggleButton(true);
@@ -162,6 +163,7 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
   font = PushButtonRec->font();
   font.setPointSize(9);
   PushButtonRec->setFont(font);
+  PushButtonRec->setPaletteBackgroundColor(QColor(64, 64, 128));
   PushButtonRec->setPaletteForegroundColor(QColor(255, 0, 0));
   PushButtonRec->setText("R");
   PushButtonRec->setToggleButton(true);
@@ -169,13 +171,26 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
   PushButtonRec->setMaximumWidth(PushButtonRec->sizeHint().width());
 
   //!!
-#if 0
+//#if 0
+  // effect editor
   {
-    QPushButton* Button = new QPushButton(i18n("Edit Effects..."), HBoxTop);
+    QPushButton* Button = new QPushButton(i18n("Edit FX..."), HBoxTop);
     connect(Button, SIGNAL(clicked()), this, SLOT(slotEditEffects()));
+
+    // bypass button
+    PushButtonBypass = new QPushButton(HBoxTop);
+    QFont font = PushButtonBypass->font();
+    font.setPointSize(9);
+    PushButtonBypass->setFont(font);
+    PushButtonBypass->setPaletteBackgroundColor(QColor(64, 64, 128));
+    PushButtonBypass->setPaletteForegroundColor(QColor(192, 128, 255));
+    PushButtonBypass->setText("B");
+    PushButtonBypass->setToggleButton(true);
+    PushButtonBypass->setOn(false);
+    PushButtonBypass->setMaximumWidth(PushButtonBypass->sizeHint().width());
   }
-#endif
-  
+//#endif
+
   HBoxTop->setMaximumWidth(400);
   HBoxTop->setMinimumWidth(400);
 
@@ -192,8 +207,11 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
           this, SIGNAL(fileNameChanged(const QString&)));
   connect(IntNumInputLevel, SIGNAL(valueChanged(int)), this, SIGNAL(levelChanged(int)));
   connect(IntNumInputPan, SIGNAL(valueChanged(int)), this, SIGNAL(panChanged(int)));
+  connect(PushButtonMute, SIGNAL(toggled(bool)), this, SLOT(slotToggledMute(bool)));
+  connect(PushButtonRec, SIGNAL(toggled(bool)), this, SLOT(slotToggledRec(bool)));
   connect(PushButtonMute, SIGNAL(toggled(bool)), this, SIGNAL(muteToggled(bool)));
   connect(PushButtonRec, SIGNAL(toggled(bool)), this, SIGNAL(recToggled(bool)));
+  connect(PushButtonBypass, SIGNAL(toggled(bool)), this, SIGNAL(bypassToggled(bool)));
   connect(Locator, SIGNAL(startPositionChanged(const QTime&)), 
           this, SLOT(slotSetStartPosition(const QTime&)));
   connect(Locator, SIGNAL(offsetChanged(const QTime&)), 
@@ -339,6 +357,14 @@ WVoxTrack::isMuted() const
 
 /////////////////////////////////////////////////////////////////////////////
 
+bool 
+WVoxTrack::isBypassed() const
+{
+  return PushButtonBypass->isOn();
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 bool
 WVoxTrack::isSetRec() const
 {
@@ -355,6 +381,14 @@ WVoxTrack::isBindedToFile() const
 
 /////////////////////////////////////////////////////////////////////////////
 
+QValueVector<CLadspaEffect> 
+WVoxTrack::effects() const 
+{
+  return fxs;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 CTrackInf 
 WVoxTrack::stateInTrackInf() const
 {
@@ -371,6 +405,7 @@ WVoxTrack::stateInTrackInf() const
   trackInfReturn.timeLength      = timeLength;
   trackInfReturn.bMute           = PushButtonMute->isOn();
   trackInfReturn.bRecPort        = PushButtonRec->isOn();
+  trackInfReturn.vEffects        = fxs;
 
   return trackInfReturn;
 }
@@ -527,6 +562,7 @@ WVoxTrack::setStateByTrackInf(const CTrackInf& trackInfSet)
   timeLength        = trackInfSet.timeLength;
   PushButtonMute->setOn(trackInfSet.bMute);
   PushButtonRec->setOn(trackInfSet.bRecPort);
+  fxs = trackInfSet.vEffects;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -920,7 +956,10 @@ WVoxTrack::slotEditEffects()
 {
   WLadspaDialog ladspaDialog(getenv("LADSPA_PATH"), this);
 
+  ladspaDialog.setEffects(fxs);
   if ( ladspaDialog.exec() == QDialog::Accepted ) {
+    ladspaDialog.getEffects(fxs);
+    emit effectsChanged(fxs);
   }
 }
 
@@ -942,4 +981,18 @@ WVoxTrack::slotMovedContents(int x)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::slotToggledMute(bool)
+{
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+WVoxTrack::slotToggledRec(bool)
+{
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 #include "wvoxtrack.moc"
