@@ -35,10 +35,12 @@
 #include <qpopupmenu.h>
 #include <qpushbutton.h>
 #include <qdom.h>
+#include <qvaluevector.h>
 #include <knuminput.h>
 #include "wfilechooser.h"
 #include "wsoundlocator.h"
 #include "ctrackinf.h"
+#include "cladspaeffect.h"
 
 /*-------------------------------------------------------------------------*/
 /*! \class  WVoxTrack
@@ -117,6 +119,10 @@ public:
   bool      isSetRec() const;
   //! \brief ե̾ꤵƤ뤫ɤ֤
   bool      isBindedToFile() const;
+  //! \brief եȤ֤
+  QValueVector<CLadspaEffect> effects() const;
+  //! \brief ХѥꤵƤ뤫ɤ롣
+  bool      isBypassed() const;
   //! \brief ȥåξ礷Ƽ롣
   CTrackInf stateInTrackInf() const;
   //! \brief  󥹥󥹤ξ֤DOM֤
@@ -222,6 +228,8 @@ private:
   QPushButton   *PushButtonMute;
   //! 쥳ǥ󥰤ON/OFFꤹܥ
   QPushButton   *PushButtonRec;
+  //! ХѥON/OFFꤹܥ
+  QPushButton   *PushButtonBypass;
   //! ɥ
   WSoundLocator *Locator;
   //! ݥåץåץ˥塼
@@ -244,6 +252,8 @@ private:
   int            nMenuIDEffects;
   //! ˥塼ID(ץѥƥ)
   int            nMenuIDProperty;
+  //! եȡ
+  QValueVector<CLadspaEffect> fxs;
 
   //! \brief åȤꡣ
   //! 󥹥ȥ饯Τ߸ƤӽФġ
@@ -293,6 +303,10 @@ private slots:
 
   //! ѡ
   void slotMovedContents(int x);
+  //! ߥ塼ȥȥܥȥΥåȡ
+  void slotToggledMute(bool bToggled);
+  //! ϿȥܥȥΥåȡ
+  void slotToggledRec(bool bToggled);
 
 signals:
   //! \brief ץ쥤ХåǥХѹΥʥ롣
@@ -313,10 +327,15 @@ signals:
   void recToggled(bool);
   //! \brief ϰ֤ѹ줿Υʥ롣
   void startPositionChanged(const QTime&);
-  //! \brief Ͽ֤ѹ줿Υʥ롣
+  //! \brief եåȤѹ줿Υʥ롣
   void offsetChanged(const QTime&);
-  //! \brief Ͽ֤ѹ줿Υʥ롣
+  //! \brief Ĺѹ줿Υʥ롣
   void lengthChanged(const QTime&);
+  //! \brief եȤѹ줿Υʥ롣
+  void effectsChanged(const QValueVector<CLadspaEffect>&);
+  //! \brief Хѥ֤ѹ줿Υʥ롣
+  void bypassToggled(bool);
+
   //! \brief ץѥƥɽ׵ᤵ줿Υʥ롣
   void propertyDemanded(const CTrackInf&);
 
